@@ -69,7 +69,7 @@ class CGFeedMaker extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.0.14';
+    return '1.0.15';
   }
 
 
@@ -167,7 +167,7 @@ class CGFeedMaker extends CGExtensions
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.8.2";
+    return "1.9.4.3";
   }
 	
 	
@@ -264,26 +264,31 @@ class CGFeedMaker extends CGExtensions
     $params['showtemplate'] = 'false';
     $prettyurl = "feeds/$feedalias";
 
-    $url = $this->CreateURL($id,'default',$pageid,$params,false,$prettyurl);
+    $url = $this->create_url($id,'default',$pageid,$params,false,false,$prettyurl);
     $is_pretty = (strpos($url,'/feeds') !== FALSE);
-    if( $is_pretty &&
-        (isset($config['assume_mod_rewrite']) && $config['assume_mod_rewrite']) ||
-	(isset($config['internal_pretty_urls']) && $config['internal_pretty_urls']) )
+    if( $is_pretty )
       {
-        // remove the old extension from the URL if not empty
-        if( !empty($config['page_extension']) )
-        {
-          $url = substr($url,0,strlen($url)-strlen($config['page_extension']));
-        }
-        if( $ext == '' )
-          {
-            $ext = $this->GetPreference('feed_extension','rss');
-          }
-        if( !startswith($ext,'.') )
-          {
-            $ext = '.'.$ext;
-          }
-        $url .= $ext;
+	if( isset($config['url_rewriting']) && $config['url_rewriting'] != 'none' )
+	  {
+	    if( !empty($config['page_extension']) )
+	      {
+		// remove the old extension from the URL if not empty
+		$url = substr($url,0,strlen($url)-strlen($config['page_extension']));
+	      }
+	    if( $ext == '' )
+	      {
+		$ext = $this->GetPreference('feed_extension','rss');
+	      }
+	    if( !startswith($ext,'.') )
+	      {
+		$ext = '.'.$ext;
+	      }
+	    $url .= $ext;
+	  }
+      }
+    else
+      {
+	$url .= '&showtemplate=false';
       }
 
     return $url;
